# requests

LIST_PARAMS = {
    "gk_version": "gz-gaokao",
    "t": "general",
    "q": "",
    "correction": "1",
    "offset": "0",
    "limit": "20",
    "filter_fields": "",
    "lc_idx": "0",
    "show_all_topics": "0",
    "search_source": "Normal"
}

LIST_HEADERS = {
    "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64)"
                  " AppleWebKit/537.36 (KHTML, like Gecko) Chrome/108.0.0.0 Safari/537.36",
    "x-api-version": "3.0.91",
    "x-zse-93": "101_3_3.0",
}
